from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean
import os

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean)

setup(name='elisa-plugin-hal',
    version='0.0.1', 
    description='Listen to HAL and inform elisa about changes',
    license='GPL3', 
    author='Elisa Developers',
    author_email='elisa@lists.fluendo.com',
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    cmdclass=cmdclass,
    entry_points="""
    [elisa.core.components.resource_provider]
    HALResource = elisa.plugins.hal.hal_resource:HALResource
    """)
